==> qtjambi-webenginewidgets-5.15.15-sources.jar: io/qt/webengine/widgets/QWebEngineClientCertificateSelection.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QWebEngineClientCertificateSelection</p>
 */
public class QWebEngineClientCertificateSelection extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineClientCertificateSelection(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QWebEngineClientCertificateSelection instance, io.qt.webengine.widgets.QWebEngineClientCertificateSelection arg__1);
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QVector<io.qt.network.@NonNull QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QVector<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl host(){
        return host_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl host_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineClientCertificateSelection)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1) {
        assign(arg__1);
    }
    
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1){
        assign_native_cref_QWebEngineClientCertificateSelection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineClientCertificateSelection(long __this__nativeId, long arg__1);
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void select(io.qt.network.@NonNull QSslCertificate certificate){
        select_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @QtUninvokable
    private native void select_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    @QtUninvokable
    public final void selectNone(){
        selectNone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void selectNone_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineClientCertificateSelection(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineClientCertificateSelection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineClientCertificateSelection clone_native(long __this_nativeId);
}

==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineClientCertificateSelection.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineClientCertificateSelection</code></p>
 */
public class QWebEngineClientCertificateSelection extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)</code></p>
     */
    public QWebEngineClientCertificateSelection(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QWebEngineClientCertificateSelection instance, io.qt.webengine.widgets.QWebEngineClientCertificateSelection arg__1);
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>certificates()const</code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QVector<io.qt.network.@NonNull QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QVector<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>host()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl host(){
        return host_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl host_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>operator=(QWebEngineClientCertificateSelection)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1){
        assign_native_cref_QWebEngineClientCertificateSelection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineClientCertificateSelection(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>select(QSslCertificate)</code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void select(io.qt.network.@NonNull QSslCertificate certificate){
        select_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @QtUninvokable
    private native void select_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    /**
     * <p>See <code>QWebEngineClientCertificateSelection::<wbr>selectNone()</code></p>
     */
    @QtUninvokable
    public final void selectNone(){
        selectNone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void selectNone_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineClientCertificateSelection(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineClientCertificateSelection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineClientCertificateSelection clone_native(long __this_nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineClientCertificateSelection)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineClientCertificateSelection arg__1) {
        assign(arg__1);
    }
}
